@@ -38,7 +38,7 @@ import shutil
 from collections import MutableSet
 from update_tasks import EmergeMark
 
-from calculate.lib.utils.git import Git, GitError, MTimeKeeper
+from calculate.lib.utils.git import Git, GitError, MTimeKeeper, NotGitError
 from calculate.lib.utils.portage import (Layman, EmergeLog,
                                          EmergeLogNamedTask, PackageList,
                                          PackageInformation,
@@ -336,14 +336,15 @@ class Update(MethodsInterface):
                         return "skip"
                     return True
                 except GitError as e:
-                    if e.addon:
-                        self.printWARNING(str(e.addon))
-                    self.printWARNING(str(e))
-                    self.endTask(False)
-                    self.startTask(
-                        _("Re-fetching the {name} repository").format(
-                            name=repname))
-                    self.addProgress()
+                    if not isinstance(e, NotGitError):
+                        if e.addon:
+                            self.printWARNING(str(e.addon))
+                        self.printWARNING(str(e))
+                        self.endTask(False)
+                        self.startTask(
+                            _("Re-fetching the {name} repository").format(
+                                name=repname))
+                        self.addProgress()
                     rpath_new = "%s_new" % rpath
                     try:
                         self._syncRepository(repname, url, rpath_new, revision,
